@@ -123,11 +123,19 @@ def net_vlan(context, name, inventory_hostname=None):
     return net_attr(context, name, 'vlan', inventory_hostname)
 
 
-net_mtu = _make_attr_filter('mtu')
+@jinja2.contextfilter
+def net_mtu(context, name, inventory_hostname=None):
+    mtu = net_attr(context, name, 'mtu', inventory_hostname)
+    if mtu is not None:
+        mtu = int(mtu)
+    return mtu
+
+
 net_routes = _make_attr_filter('routes')
 net_rules = _make_attr_filter('rules')
 net_physical_network = _make_attr_filter('physical_network')
 net_bootproto = _make_attr_filter('bootproto')
+net_defroute = _make_attr_filter('defroute')
 
 
 @jinja2.contextfilter
@@ -190,11 +198,13 @@ def net_interface_obj(context, name, inventory_hostname=None):
             "Network interface for network '%s' on host '%s' not found" %
             (name, inventory_hostname))
     ip = net_ip(context, name, inventory_hostname)
-    if ip is None:
-        ip = '0.0.0.0'
     cidr = net_cidr(context, name, inventory_hostname)
     netmask = net_mask(context, name, inventory_hostname)
     gateway = net_gateway(context, name, inventory_hostname)
+    if ip is None:
+        ip = ''
+        gateway = None
+        netmask = None
     vlan = net_vlan(context, name, inventory_hostname)
     mtu = net_mtu(context, name, inventory_hostname)
     routes = net_routes(context, name, inventory_hostname)
@@ -202,6 +212,9 @@ def net_interface_obj(context, name, inventory_hostname=None):
         routes = [_route_obj(route) for route in routes]
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
+    defroute = net_defroute(context, name, inventory_hostname)
+    vip_address = net_vip_address(context, name, inventory_hostname)
+    allowed_addresses = [vip_address] if vip_address else None
     interface = {
         'device': device,
         'address': ip,
@@ -212,6 +225,8 @@ def net_interface_obj(context, name, inventory_hostname=None):
         'route': routes,
         'rules': rules,
         'bootproto': bootproto or 'static',
+        'defroute': defroute,
+        'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
     interface = {k: v for k, v in interface.items() if v is not None}
@@ -231,11 +246,13 @@ def net_bridge_obj(context, name, inventory_hostname=None):
             "Network interface for network '%s' on host '%s' not found" %
             (name, inventory_hostname))
     ip = net_ip(context, name, inventory_hostname)
-    if ip is None:
-        ip = '0.0.0.0'
     cidr = net_cidr(context, name, inventory_hostname)
     netmask = net_mask(context, name, inventory_hostname)
     gateway = net_gateway(context, name, inventory_hostname)
+    if ip is None:
+        ip = ''
+        gateway = None
+        netmask = None
     vlan = net_vlan(context, name, inventory_hostname)
     mtu = net_mtu(context, name, inventory_hostname)
     ports = net_bridge_ports(context, name, inventory_hostname)
@@ -244,6 +261,9 @@ def net_bridge_obj(context, name, inventory_hostname=None):
         routes = [_route_obj(route) for route in routes]
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
+    defroute = net_defroute(context, name, inventory_hostname)
+    vip_address = net_vip_address(context, name, inventory_hostname)
+    allowed_addresses = [vip_address] if vip_address else None
     interface = {
         'device': device,
         'address': ip,
@@ -255,6 +275,8 @@ def net_bridge_obj(context, name, inventory_hostname=None):
         'route': routes,
         'rules': rules,
         'bootproto': bootproto or 'static',
+        'defroute': defroute,
+        'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
     interface = {k: v for k, v in interface.items() if v is not None}
@@ -274,11 +296,13 @@ def net_bond_obj(context, name, inventory_hostname=None):
             "Network interface for network '%s' on host '%s' not found" %
             (name, inventory_hostname))
     ip = net_ip(context, name, inventory_hostname)
-    if ip is None:
-        ip = '0.0.0.0'
     cidr = net_cidr(context, name, inventory_hostname)
     netmask = net_mask(context, name, inventory_hostname)
     gateway = net_gateway(context, name, inventory_hostname)
+    if ip is None:
+        ip = ''
+        gateway = None
+        netmask = None
     vlan = net_vlan(context, name, inventory_hostname)
     mtu = net_mtu(context, name, inventory_hostname)
     mode = net_bond_mode(context, name, inventory_hostname)
@@ -293,6 +317,9 @@ def net_bond_obj(context, name, inventory_hostname=None):
         routes = [_route_obj(route) for route in routes]
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
+    defroute = net_defroute(context, name, inventory_hostname)
+    vip_address = net_vip_address(context, name, inventory_hostname)
+    allowed_addresses = [vip_address] if vip_address else None
     interface = {
         'device': device,
         'address': ip,
@@ -310,6 +337,8 @@ def net_bond_obj(context, name, inventory_hostname=None):
         'route': routes,
         'rules': rules,
         'bootproto': bootproto or 'static',
+        'defroute': defroute,
+        'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
     interface = {k: v for k, v in interface.items() if v is not None}
@@ -464,6 +493,7 @@ class FilterModule(object):
             'net_rules': net_rules,
             'net_physical_network': net_physical_network,
             'net_bootproto': net_bootproto,
+            'net_defroute': net_defroute,
             'net_interface_obj': net_interface_obj,
             'net_bridge_obj': net_bridge_obj,
             'net_bond_obj': net_bond_obj,
