@@ -12,6 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import base64
+import glob
+import itertools
 import logging
 import os
 import six
@@ -24,6 +27,49 @@ import yaml
 LOG = logging.getLogger(__name__)
 
 
+def get_data_files_path(*relative_path):
+    """Given a relative path to a data file, return the absolute path"""
+    # Detect editable pip install / python setup.py develop and use a path
+    # relative to the source directory
+    return os.path.join(_get_base_path(), *relative_path)
+
+
+def _detect_install_prefix(path):
+    script_path = os.path.realpath(path)
+    script_path = os.path.normpath(script_path)
+    components = script_path.split(os.sep)
+    # use heuristic: anything before 'lib' in path is the prefix
+    if 'lib' not in components:
+        return None
+    prefix = itertools.takewhile(
+        lambda x: x != "lib",
+        components
+    )
+    prefix_path = os.sep.join(prefix)
+    return prefix_path
+
+
+def _get_base_path():
+    override = os.environ.get("KAYOBE_DATA_FILES_PATH")
+    if override:
+        return os.path.join(override)
+    egg_glob = os.path.join(
+        sys.prefix, 'lib*', 'python*', '*-packages', 'kayobe.egg-link'
+    )
+    egg_link = glob.glob(egg_glob)
+    if egg_link:
+        with open(egg_link[0], "r") as f:
+            realpath = f.readline().strip()
+        return os.path.join(realpath)
+
+    prefix = _detect_install_prefix(__file__)
+    if prefix:
+        return os.path.join(prefix, "share", "kayobe")
+
+    # Assume uninstalled
+    return os.path.join(os.path.realpath(__file__), "..")
+
+
 def yum_install(packages):
     """Install a list of packages via Yum."""
     cmd = ["sudo", "yum", "-y", "install"]
@@ -131,3 +177,34 @@ def run_command(cmd, quiet=False, check_output=False, **kwargs):
         return subprocess.check_output(cmd, **kwargs)
     else:
         subprocess.check_call(cmd, **kwargs)
+
+
+def quote_and_escape(value):
+    """Quote and escape a string.
+
+    Adds enclosing single quotes to the string passed, and escapes single
+    quotes within the string using backslashes. This is useful for passing
+    'extra vars' to Ansible. Without this, Ansible only uses the part of the
+    string up to the first whitespace.
+
+    :param value: the string to quote and escape.
+    :returns: the quoted and escaped string.
+    """
+    if not isinstance(value, six.string_types):
+        return value
+    return "'" + value.replace("'", "'\\''") + "'"
+
+
+def escape_jinja(string):
+    """Escapes a string so that jinja template variables are not expanded
+
+    :param string: the string to escape
+    :return: the escaped string
+    """
+    # We base64 encode the string to avoid the need to escape characters.
+    # This is because ansible has some parsing quirks that makes it fairly
+    # hard to escape stuff in generic way.
+    # See: https://github.com/ansible/ansible/issues/10464
+
+    b64_value = base64.b64encode(string.encode())
+    return ''.join(('{{', "'", b64_value.decode(), "' | b64decode ", '}}'))
